@@ -8,11 +8,11 @@ PDL::Stats - a collection of statistics modules in Perl Data Language, with a qu
 
 =head1 VERSION
 
-Version 0.5.0
+Version 0.5.1
 
 =cut
 
-$VERSION = '0.5.0';
+$VERSION = '0.5.1';
 
 $PDL::onlinedoc->scan(__FILE__) if $PDL::onlinedoc;
 
@@ -21,7 +21,7 @@ $PDL::onlinedoc->scan(__FILE__) if $PDL::onlinedoc;
 
 Loads modules named below, making the functions available in the current namespace.
 
-Documentations online at http://pdl-stats.sourceforge.net
+Properly formated documentations online at http://pdl-stats.sf.net
  
 =head1 SYNOPSIS
 
